@@ -3,11 +3,11 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.8   update date: 2023-12-04
+# Version : 1.4.9   update date: 2024-06-20
 ##################################################################
 ##### Defind env
 export LANG=C
-loginfo(){
+_loginfo(){
   echo -e "[$(date +'%Y-%m-%d %H:%M:%S')] $*"
 }
 ##### Get Parameter
@@ -21,21 +21,30 @@ do
     -s) DBS1GB="$2";      shift 2 ;;
     -l) GBASELOCALE="$2"; shift 2 ;;
     -o) SOFTONLY="$2";    shift 2 ;;
-    -u) USER_NAME="$2";   shift 2 ;;
+    -u) USER_USER="$2";   shift 2 ;;
+    -n) USER_SERV="$2";   shift 2 ;;
+    -c) USER_CPU="$2";    shift 2 ;;
+    -m) USER_MEM="$2";    shift 2 ;;
+    -t) USER_INST="$2";   shift 2 ;;	
     *)
-        cat <<!
+        cat <<EOF
 Usage:
-    AutoInit_GBase8s.sh [-d path] [-i path] [-p path] [-s y|n] [-l locale] [-u user] [-o y|n]
+    AutoInit_GBase8s.sh [-d path] [-i path] [-p path] [-s y|n] [-l locale] [-u user] [-o y|n] 
+	                    [-n servername] [-c num_of_cpu] [-m num_of_memory] [-t type_of_instance]
 
         -d path    The path of dbspace.
         -i path    The path of install software.
         -p path    The path of home path.
         -s y|n     Value of dbspace is 1GB? Yes/No, default is N.
         -u user    The user name for SYSDBA, gbasedbt/informix, default is gbasedbt
-        -l locale  DB_LOCALE/CLIENT_LOCALE value.
+        -l locale  DB_LOCALE/CLIENT_LOCALE/SERVER_LOCALE value.
         -o y|n     Only install software? Yes/No, default is N.
+        -n NAME    Servername, default is gbase01.
+        -c NUM     Number of CPU use.
+        -m NUM     Number of MB Memory use.
+        -t TYPE    Type of instance will install, [small], if use this, ignore -c and -m. 
 
-!
+EOF
         exit 1
         ;;
   esac
@@ -43,37 +52,32 @@ done
 ##### Define Parameter
 USER_NAME=${USER_NAME:-gbasedbt}
 if [ x"$USER_NAME" = "xgbasedbt" -o x"$USER_NAME" = "xinformix" ]; then
-   loginfo "The SYSDBA user is: $USER_NAME"
+   _loginfo "The SYSDBA user is: $USER_NAME"
 else
    echo "Username error!"
    exit 1
 fi
-USER_UPPER=$(echo $USER_NAME|tr [a-z] [A-Z])
+USER_UPPER=$(echo $USER_NAME|tr "[a-z]" "[A-Z]")
 USER_HOME=${USER_HOME:-/home/gbase}
 USER_PASS=GBase123\$%
 INSTALL_DIR=${INSTALL_DIR:-/opt/gbase}
-GBASESERVER=gbase01
+GBASESERVER=${USER_SERV:-gbase01}
 GBASELOCALE=${GBASELOCALE:-zh_CN.utf8}
+USER_CPU=${USER_CPU:-0}
+USER_MEM=${USER_MEM:-0}
+USER_INST=${USER_INST:-none}
 PORTNO=9088
 PORTSSL=9089
-
 DATADIR=${DATADIR:-/data/gbase}
-### dbspace init size.
 DBS1GB=${DBS1GB:-n}
-ROOTSIZE=1024000
-PLOGSIZE=2048000
-LLOGSIZE=4096000
-SBSPACESIZE=4096000
-TEMPSIZE=4096000
-DATASIZE=10240000
 
-if [[ x"$DBS1GB" = xy || x"$DBS1GB" = xY ]]; then
-  ROOTSIZE=1024000
-  PLOGSIZE=1024000
-  LLOGSIZE=1024000
-  SBSPACESIZE=1024000
-  TEMPSIZE=1024000
-  DATASIZE=1024000
+TMP_USER_CPU=$(echo ${USER_CPU} | sed 's/[0-9]//g')
+if [ ! x"${TMP_USER_CPU}" = x ]; then
+  USER_CPU=0
+fi
+TMP_USER_MEM=$(echo ${USER_MEM} | sed 's/[0-9]//g')
+if [ ! x"${TMP_USER_MEM}" = x ]; then
+  USER_MEM=0
 fi
 
 WORKDIR=$(pwd)
@@ -94,7 +98,7 @@ fi
 
 SOFTPACKNAME=$(ls GBase*.tar 2>/dev/null)
 if [ x"$SOFTPACKNAME" = x ]; then
-  loginfo "ERROR: GBase Database Soft Package not found."
+  _loginfo "ERROR: GBase Database Soft Package not found."
   exit 2
 fi
 
@@ -106,13 +110,44 @@ fi
 
 # IP use first IPADDR
 # IPADDR=$(ifconfig -a | awk '/inet /{printf (split($2,a,":")>1)?a[2]:$2" "}')
-loginfo "IPADDR: 0.0.0.0"
-loginfo "Datadir: $DATADIR"
+_loginfo "IPADDR: 0.0.0.0"
+_loginfo "Datadir: $DATADIR"
 
 ##### Get env
 NUMCPU=$(awk '/^processor/{i++}END{printf("%d\n",i)}' /proc/cpuinfo)
 NUMMEM=$(awk '/^MemTotal:/{printf("%d\n",$2/1000)}' /proc/meminfo)
 
+if [ x"${USER_INST}" = "xsmall" ]; then
+  NUMCPU=1
+  NUMMEM=2048
+  DBS1GB=y
+else
+  if [[ ${USER_CPU} -gt 0 && ${USER_CPU} -lt ${NUMCPU} ]]; then
+    NUMCPU=${USER_CPU}
+  fi
+  if [[ ${USER_MEM} -gt 0 && ${USER_MEM} -lt ${NUMMEM} ]]; then
+    NUMMEM=${USER_MEM}
+  fi
+fi
+
+### dbspace init size.
+# default chunk size, 16G
+ROOTSIZE=1024000
+PLOGSIZE=2048000
+LLOGSIZE=4096000
+SBSPACESIZE=4096000
+TEMPSIZE=4096000
+DATASIZE=10240000
+
+if [[ x"$DBS1GB" = xy || x"$DBS1GB" = xY ]]; then
+  ROOTSIZE=1024000
+  PLOGSIZE=1024000
+  LLOGSIZE=1024000
+  SBSPACESIZE=1024000
+  TEMPSIZE=1024000
+  DATASIZE=1024000
+fi
+
 if [ ${NUMCPU:-0} -eq 0 ]; then
   echo "GET cpu information error."
   exit 2 
@@ -122,46 +157,40 @@ elif [ $NUMCPU -le 4 ]; then
 else
   CPUVP=$(expr $NUMCPU - 1)
   CFG_NETPOOL=$(expr $NUMCPU / 3)
+  [ ${CFG_NETPOOL} -gt 10 ] && CFG_NETPOOL=10
 fi
 
 if [ ${NUMMEM:-0} -eq 0 ]; then
   echo "GET memory information error."
   exit 2
 elif [ $NUMMEM -le 2048 ]; then
-  # mem less then 1G, use direct_io, only 2k buffpool
-  CFG_DIRECT_IO=1
+  # mem less then 2G
   CFG_LOCKS=50000
   CFG_SHMVIRTSIZE=384000
   CFG_2KPOOL=20000
   CFG_16KPOOL=10000 
 elif [ $NUMMEM -le 4096 ]; then
-  # mem less then 4G, use direct_io, only 2k buffpool
-  CFG_DIRECT_IO=1
+  # mem less then 4G
   CFG_LOCKS=200000
   CFG_SHMVIRTSIZE=512000
   CFG_2KPOOL=50000
   CFG_16KPOOL=20000 
 elif [ $NUMMEM -le 8192 ]; then
-  # mem less then 8G, use direct_io, only 2k buffpool
-  CFG_DIRECT_IO=1
-  MUTI=$(expr $NUMMEM / 2000)
-  [ $MUTI -eq 0 ] && MUTI=1
+  # mem less then 8G
   CFG_LOCKS=1000000
   CFG_SHMVIRTSIZE=512000
   CFG_2KPOOL=500000
   CFG_16KPOOL=100000
 elif [ $NUMMEM -le 32768 ]; then
-  # mem >8G && < 32G, not use direct_io, use 2k & 16k buffpool
-  CFG_DIRECT_IO=0
+  # mem >8G && < 32G, use 2k & 16k buffpool
   MUTI=$(expr $NUMMEM / 8000)
   [ $MUTI -eq 0 ] && MUTI=2
   CFG_LOCKS=5000000
-  CFG_SHMVIRTSIZE=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*1024000}')
+  CFG_SHMVIRTSIZE=$(echo "$MUTI" | awk '{printf("%d\n",($1 - 1) * 1024000)}')
   CFG_2KPOOL=500000
-  CFG_16KPOOL=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*200000}')
+  CFG_16KPOOL=$(echo "$MUTI" | awk '{printf("%d\n",($1 - 1) * 200000)}')
 else
   # mem > 32G
-  CFG_DIRECT_IO=0
   CFG_LOCKS=5000000
   CFG_SHMVIRTSIZE=4096000
   CFG_2KPOOL=1000000
@@ -177,7 +206,7 @@ if [ $? -eq 0 ];then
     echo "User: ${USER_NAME} exists, you must check !" 
     exit 2
 fi
-loginfo "Creating group [${USER_NAME}] and user [${USER_NAME}] with HOME [$USER_HOME]."
+_loginfo "Creating group [${USER_NAME}] and user [${USER_NAME}] with HOME [$USER_HOME]."
 groupadd ${USER_NAME} 2>/dev/null
 if [ $? -gt 0 ]; then
   echo "Create group [${USER_NAME}] error."
@@ -185,7 +214,7 @@ if [ $? -gt 0 ]; then
 fi
 TMPUSER_HOME=${USER_HOME%/*}
 if [ ! -d ${TMPUSER_HOME} ]; then
-  loginfo "Creating directory where user home will build: ${TMPUSER_HOME}" 
+  _loginfo "Creating directory where user home will build: ${TMPUSER_HOME}" 
   mkdir -p ${TMPUSER_HOME}
 fi
 useradd -g ${USER_NAME} -d ${USER_HOME:-/home/${USER_NAME}} -m -s /bin/bash ${USER_NAME} 2>/dev/null
@@ -204,7 +233,7 @@ chmod 0777 ${USER_HOME}/users 2>/dev/null
 chown ${USER_NAME}:${USER_NAME} ${USER_HOME}/users 2>/dev/null
 
 ##### Unzip software and install
-loginfo "Unziping [${SOFTPACKNAME}]."
+_loginfo "Unziping [${SOFTPACKNAME}]."
 mkdir -p ${WORKDIR}/install 2>/dev/null
 cd ${WORKDIR}/install
 tar -xf ${WORKDIR}/${SOFTPACKNAME} 2>/dev/null
@@ -213,7 +242,7 @@ if [ ! -x "ids_install" ]; then
   exit 4
 fi
 if [ -x "onsecurity" ]; then
-  loginfo "Check path INSTALL_DIR($INSTALL_DIR) security."
+  _loginfo "Check path INSTALL_DIR($INSTALL_DIR) security."
   ${WORKDIR}/install/onsecurity $INSTALL_DIR >/dev/null 2>&1
   if [ $? -gt 0 ]; then
     echo "INSTALL_DIR: $INSTALL_DIR not security, Plase Check."
@@ -226,15 +255,17 @@ chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR 2>/dev/null
 chmod 0755 $INSTALL_DIR 2>/dev/null
 
 # ids_install
-loginfo "Execute software install, this will take a moment."
+mkdir -p ${WORKDIR}/tmp 2>/dev/null
+export IATEMPDIR=${WORKDIR}/tmp
+_loginfo "Execute software install, this will take a moment."
 timeout 1800 ${WORKDIR}/install/ids_install -i silent -DLICENSE_ACCEPTED=TRUE -DUSER_INSTALL_DIR=${INSTALL_DIR:-/opt/${USER_NAME}}
 if [ ! $? -eq 0 ]; then
-  loginfo "Install Error! remove install file."
+  _loginfo "Install Error! remove install file."
   if [ -d ${INSTALL_DIR:-/opt/${USER_NAME}} ]; then
     rm -rf ${INSTALL_DIR:-/opt/${USER_NAME}}
   fi
-  userdel -r gbasedbt 2>/dev/null
-  groupdel gbasedbt 2>/dev/null
+  userdel -r ${USER_NAME} 2>/dev/null
+  groupdel ${USER_NAME} 2>/dev/null
   exit 6
 fi
 
@@ -243,14 +274,14 @@ fi
 echo "USERS:daemon" > /etc/${USER_NAME}/allowed.surrogates
 
 # profile
-loginfo "Building ~${USER_NAME}/.bash_profile ."
+_loginfo "Building ~${USER_NAME}/.bash_profile ."
 cat >> $USER_HOME/.bash_profile <<EOF 2>/dev/null
 export ${USER_UPPER}DIR=${INSTALL_DIR}
 export ${USER_UPPER}SERVER=${GBASESERVER}
 export ONCONFIG=onconfig.\$${USER_UPPER}SERVER
-export PATH=\$${USER_UPPER}DIR/bin:\${PATH}
+export PATH=\$${USER_UPPER}DIR/bin:\$${USER_UPPER}DIR/sbin:\$${USER_UPPER}DIR/sbin:\${PATH}
 export ${USER_UPPER}SQLHOSTS=${INSTALL_DIR}/etc/sqlhosts
-
+export SERVER_LOCALE=${GBASELOCALE}
 export DB_LOCALE=${GBASELOCALE}
 export CLIENT_LOCALE=${GBASELOCALE}
 export GL_USEGLU=1
@@ -258,9 +289,11 @@ export GL_USEGLU=1
 export DBDATE="Y4MD-"
 export DBACCESS_SHOW_TIME=1
 EOF
+chown ${USER_NAME}:${USER_NAME} $USER_HOME/.bash_profile
+chmod 0644 $USER_HOME/.bash_profile
 
 # sqlhosts
-loginfo "Building ${INSTALL_DIR}/etc/sqlhosts ."
+_loginfo "Building ${INSTALL_DIR}/etc/sqlhosts ."
 # echo "$GBASESERVER onsoctcp 0.0.0.0 ${PORTNO:-9088}" > $INSTALL_DIR/etc/sqlhosts
 cat > $INSTALL_DIR/etc/sqlhosts <<EOF 2>/dev/null
 ${GBASESERVER}     onsoctcp 0.0.0.0 ${PORTNO:-9088}
@@ -274,7 +307,7 @@ CFGFILE=$INSTALL_DIR/etc/onconfig.$GBASESERVER
 cp $INSTALL_DIR/etc/onconfig.std $CFGFILE
 chown ${USER_NAME}:${USER_NAME} $CFGFILE
 chmod 0644 $CFGFILE
-loginfo "Building $CFGFILE ."
+_loginfo "Building $CFGFILE ."
 
 sed -i "s#^ROOTPATH.*#ROOTPATH $DATADIR/rootchk#g" $CFGFILE
 sed -i "s#^ROOTSIZE.*#ROOTSIZE $ROOTSIZE#g" $CFGFILE
@@ -285,12 +318,10 @@ sed -i "s#^LTAPEDEV.*#LTAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^USERMAPPING.*#USERMAPPING ADMIN#g" $CFGFILE
 sed -i "s#^DEF_TABLE_LOCKMODE.*#DEF_TABLE_LOCKMODE row#g" $CFGFILE
 
-chown ${USER_NAME}:${USER_NAME} $CFGFILE
-
 # datadir
-loginfo "Creating DATADIR: ${DATADIR} ."
+_loginfo "Creating DATADIR: ${DATADIR} ."
 mkdir -p $DATADIR
-loginfo "Change permission for directory: $DATADIR ."
+_loginfo "Change permission for directory: $DATADIR ."
 chown ${USER_NAME}:${USER_NAME} $DATADIR
 
 DTDIR=$DATADIR
@@ -301,7 +332,7 @@ do
   if [ x"${DTDIR}" = "x" ]; then
     break
   else
-    loginfo "Change permission for directory: $DTDIR ."
+    _loginfo "Change permission for directory: $DTDIR ."
     chmod 0755 $DTDIR
   fi
   sleep 1
@@ -316,7 +347,7 @@ chmod 0660 rootchk plogchk llogchk sbspace01 tempchk01 datachk01
 cd $TMPDIR
 
 if [ "x$SOFTONLY" = xy -o "x$SOFTONLY" = xY ];then
-  loginfo "GBase 8s Database software install finished."
+  _loginfo "GBase 8s Database software install finished."
   cat <<!
 
   You MUST manually initialize the database!
@@ -326,7 +357,7 @@ if [ "x$SOFTONLY" = xy -o "x$SOFTONLY" = xY ];then
 fi
 
 # fix 330 ddlalert error
-loginfo "Creating file \$INSTALL_DIR/etc/upgraded ."
+_loginfo "Creating file \$INSTALL_DIR/etc/upgraded ."
 if [ ! -f $INSTALL_DIR/etc/upgraded ]; then
   touch $INSTALL_DIR/etc/upgraded
   chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/upgraded
@@ -334,15 +365,15 @@ if [ ! -f $INSTALL_DIR/etc/upgraded ]; then
 fi
 
 # oninit
-loginfo "Start run database init: oninit -ivy"
+_loginfo "Start run database init: oninit -ivy"
 su - ${USER_NAME} -c "timeout 1800 oninit -ivy"
 if [ ! $? -eq 0 ]; then
-  loginfo "Database init error! Please check online.log."
+  _loginfo "Database init error! Please check online.log."
   exit 1
 fi
 
 echo -e "OK"
-loginfo "Creating system database.\c"
+_loginfo "Creating system database.\c"
 for w in {1..5}
 do
   sleep 3
@@ -365,23 +396,23 @@ done
 
 ## create dbspace.
 echo -e ""
-loginfo "Creating dbspace plogdbs."
+_loginfo "Creating dbspace plogdbs."
 su - ${USER_NAME} -c "onspaces -c -d plogdbs -p $DATADIR/plogchk -o 0 -s $PLOGSIZE >/dev/null 2>&1"
 
-loginfo "Creating dbspace llogdbs."
+_loginfo "Creating dbspace llogdbs."
 su - ${USER_NAME} -c "onspaces -c -d llogdbs -p $DATADIR/llogchk -o 0 -s $LLOGSIZE >/dev/null 2>&1"
 
-loginfo "Creating dbspace tempdbs01"
-su - ${USER_NAME} -c "onspaces -c -d tempdbs01 -p $DATADIR/tempchk01 -t -o 0 -s $TEMPSIZE $PAGESIZE >/dev/null 2>&1"
-
-loginfo "Creating smart blob space sbspace01"
+_loginfo "Creating smart blob space sbspace01"
 su - ${USER_NAME} -c "onspaces -c -S sbspace01 -p $DATADIR/sbspace01 -o 0 -s $SBSPACESIZE >/dev/null 2>&1"
 
-loginfo "Creating dbspace datadbs01"
+_loginfo "Creating dbspace tempdbs01"
+su - ${USER_NAME} -c "onspaces -c -d tempdbs01 -p $DATADIR/tempchk01 -t -o 0 -s $TEMPSIZE $PAGESIZE >/dev/null 2>&1"
+
+_loginfo "Creating dbspace datadbs01"
 su - ${USER_NAME} -c "onspaces -c -d datadbs01 -p $DATADIR/datachk01 -o 0 -s $DATASIZE $PAGESIZE >/dev/null 2>&1"
 
 ## change chunk extend able on
-loginfo "Changing auto extend able on for chunk datadbs01"
+_loginfo "Changing auto extend able on for chunk datadbs01"
 ADMIN_SQLFILE=${INSTALL_DIR}/temp/admin_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $ADMIN_SQLFILE 2>&1
@@ -422,7 +453,7 @@ if [ -s $ADMIN_SQLFILE ]; then
 fi
 
 ## create mapping default user
-loginfo "Creating default user for mapping user"
+_loginfo "Creating default user for mapping user"
 ADMIN_SQLFILE=${INSTALL_DIR}/temp/mapping_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $ADMIN_SQLFILE 2>&1
@@ -436,11 +467,11 @@ if [ -s $ADMIN_SQLFILE ]; then
 fi
 
 ## physical log & logical log
-loginfo "Moving physical log to plogdbs."
+_loginfo "Moving physical log to plogdbs."
 PLOGFILE=$(echo $PLOGSIZE | awk '{printf("%d\n",substr($1,1,1) * 10 ^ (length($1) - 1))}')
 su - ${USER_NAME} -c "onparams -p -d plogdbs -s $PLOGFILE -y >/dev/null 2>&1"
 
-loginfo "Adding 10 logical log file in llogdbs."
+_loginfo "Adding 10 logical log file in llogdbs."
 LLOGFILE=$(echo $LLOGSIZE | awk '{printf("%d\n",substr($1,1,1) * 10 ^ (length($1) - 1))}')
 NEWFILE=$(expr $LLOGFILE / 10)
 [ $NEWFILE -gt 1000000 ] && NEWFILE=1000000
@@ -449,7 +480,7 @@ do
   su - ${USER_NAME} -c "onparams -a -d llogdbs -s $NEWFILE >/dev/null 2>&1"
 done
 
-loginfo "Moving CURRENT logical log to new logical file."
+_loginfo "Moving CURRENT logical log to new logical file."
 while :
 do
   CURRLOG=$(su - ${USER_NAME} -c "onmode -l; onmode -c; onstat -l" | awk '/U---C-L/{print $2}')
@@ -460,14 +491,14 @@ do
   fi
 done
 
-loginfo "Droping logical log file which in rootdbs."
+_loginfo "Droping logical log file which in rootdbs."
 for e in {1..6}
 do
   su - ${USER_NAME} -c "onparams -d -l $e -y >/dev/null 2>&1"
 done
 
 ### Build default database: testdb
-loginfo "Create database testdb."
+_loginfo "Create database testdb."
 CRDB_SQLFILE=${INSTALL_DIR}/temp/crdb_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $CRDB_SQLFILE 2>&1
@@ -481,7 +512,7 @@ if [ -s $CRDB_SQLFILE ]; then
 fi
 
 ###### change config
-#loginfo "Creating file \$INSTALL_DIR/etc/sysadmin/stop ."
+#_loginfo "Creating file \$INSTALL_DIR/etc/sysadmin/stop ."
 #if [ ! -f $INSTALL_DIR/etc/sysadmin/stop ]; then
 #  touch $INSTALL_DIR/etc/sysadmin/stop
 #  chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/sysadmin/stop
@@ -489,7 +520,7 @@ fi
 #fi
 
 ## cfg with static value
-loginfo "Optimizing database config."
+_loginfo "Optimizing database config."
 sed -i "s#^PHYSBUFF.*#PHYSBUFF 1024#g" $CFGFILE
 sed -i "s#^LOGBUFF.*#LOGBUFF 1024#g" $CFGFILE
 sed -i "s#^DYNAMIC_LOGS.*#DYNAMIC_LOGS 0#g" $CFGFILE
@@ -511,6 +542,8 @@ sed -i "s#^TEMPTAB_NOLOG.*#TEMPTAB_NOLOG 1#g" $CFGFILE
 sed -i "s#^DUMPSHMEM.*#DUMPSHMEM 0#g" $CFGFILE
 # sed -i "s#^IFX_FOLDVIEW.*#IFX_FOLDVIEW 0#g" $CFGFILE
 sed -i "s#^OPT_GOAL.*#OPT_GOAL 0#g" $CFGFILE
+sed -i "s#^TAPEBLK.*#TAPEBLK 512#g" $CFGFILE
+sed -i "s#^LTAPEBLK.*#LTAPEBLK 512#g" $CFGFILE
 
 if [ $NUMMEM -le 4096 ]; then
   sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 128000#g" $CFGFILE
@@ -519,29 +552,31 @@ fi
 # dynamic value
 sed -i "s#^NETTYPE.*#NETTYPE soctcp,${CFG_NETPOOL},200,NET#g" $CFGFILE
 sed -i "s#^VPCLASS.*cpu.*#VPCLASS cpu,num=${CPUVP},noage#g" $CFGFILE
-sed -i "s#^DIRECT_IO.*#DIRECT_IO ${CFG_DIRECT_IO}#g" $CFGFILE
 sed -i "s#^LOCKS.*#LOCKS ${CFG_LOCKS}#g" $CFGFILE
 sed -i "s#^SHMVIRTSIZE.*#SHMVIRTSIZE ${CFG_SHMVIRTSIZE}#g" $CFGFILE
 sed -i "s#^SHMADD.*#SHMADD ${CFG_SHMADD}#g" $CFGFILE
+sed -i "s#^EXTSHMADD.*#EXTSHMADD ${CFG_SHMADD}#g" $CFGFILE
 sed -i "s#^SHMTOTAL.*#SHMTOTAL ${CFG_SHMTOTAL}#g" $CFGFILE
 
 sed -i "s#^BUFFERPOOL.*size=2.*#BUFFERPOOL size=2K,buffers=${CFG_2KPOOL},lrus=8,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
 sed -i "s#^BUFFERPOOL.*size=16.*#BUFFERPOOL size=16K,buffers=${CFG_16KPOOL},lrus=64,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
 
-MSG_DATE=$(su - gbasedbt -c "onstat -c MSG_DATE 2>/dev/null")
-if [ x"${MSG_DATE}" = x ]; then
+MSG_DATE=$(su - ${USER_NAME} -c "onstat -c MSG_DATE 2>/dev/null")
+if [ x"${MSG_DATE}" = x -a "x${USER_NAME}" = "xgbasedbt" ]; then
   sed -i "/^MSGPATH/a\MSG_DATE 1" $CFGFILE
 fi
 
+chown ${USER_NAME}:${USER_NAME} $CFGFILE
+
 ####### restart database
-loginfo "Restart GBase 8s Database Server."
+_loginfo "Restart GBase 8s Database Server."
 su - ${USER_NAME} -c "timeout 1800 onmode -ky"
 sleep 5
 su - ${USER_NAME} -c "oninit -vy"
 if [ $? -eq 0 ]; then
-  loginfo "Finish."
+  _loginfo "Finish."
 else
-  loginfo "Restart Server with ERROR. Please reduce the memory parameters(SHMVIRTSIZE,BUFFPOOLS), and then restart the server."
+  _loginfo "Restart Server with ERROR. Please reduce the memory parameters(SHMVIRTSIZE,BUFFPOOLS), and then restart the server."
 fi
 cat <<EOF
 
