@@ -3,11 +3,11 @@
 # Filename: CheckEnv.sh
 # Function: Check Environment for GBase 8s install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.8   update date: 2023-12-04
+# Version : 1.4.9   update date: 2024-06-11
 ##################################################################
 ##### Defind env
 export LANG=C
-loginfo(){
+_loginfo(){
   echo -e "[$(date +'%Y-%m-%d %H:%M:%S')] $*"
 }
 
@@ -15,11 +15,11 @@ loginfo(){
 ping -c 5 1.2.4.8
 PINGOK=$?
 ##### yum install 
-if [ ${PINGOK} = 0 -a -x /usr/bin/yum ]; then
-  loginfo "Try to execute yum install.."
+if [ ${PINGOK} -eq 0 -a -x /usr/bin/yum ]; then
+  _loginfo "Try to execute yum install.."
   yum -y install unzip tar java-1.8.0-openjdk glibc-devel ncurses-libs ncurses-compat-libs libnsl libaio
-elif [ ${PINGOK} = 0 -a -x /usr/bin/apt ]; then
-  loginfo "Try to execute apt install.."
+elif [ ${PINGOK} -eq 0 -a -x /usr/bin/apt ]; then
+  _loginfo "Try to execute apt install.."
   apt -y install unzip tar openjdk-8-jdk glibc-tools libncurses5 libnsl-dev libaio-dev
 fi
 
@@ -37,7 +37,7 @@ do
     fi
   done
   if [ x"${FIND}" = x ];then
-    loginfo "$TOOL not found."
+    _loginfo "$TOOL not found."
     exit 1
   fi
 done
@@ -74,9 +74,9 @@ do
     fi
   done 
   if [ x"${FIND}" = x ];then
-    loginfo "$LIB not found."
+    _loginfo "$LIB not found."
     if [ "x${LIB}" = "xlibnsl.so.1" ]; then
-      loginfo "libnsl.so.1 missing, if install need JDK/JRE may failue !"
+      _loginfo "libnsl.so.1 missing, if install need JDK/JRE may failue !"
     else
       exit 1
     fi
@@ -87,7 +87,7 @@ done
 HOSTNAME=$(hostname)
 HOST=$(grep -i ${HOSTNAME} /etc/hosts)
 if [ x"${HOST}" = x ];then
-  loginfo "${HOSTNAME} not define in /etc/hosts, auto add it."
+  _loginfo "${HOSTNAME} not define in /etc/hosts, auto add it."
   echo "127.0.0.1 ${HOSTNAME}" >> /etc/hosts
 fi
 
